@@ -3,10 +3,15 @@
 """This module corresponds to the sdss directory in idlutils.
 """
 import os
+import re
 import numpy as np
-from astropy.extern.six import string_types
+from six import string_types
 from astropy.io import fits
+from astropy.utils.data import download_file
 from . import PydlutilsException
+from .spheregroup import spherematch
+from .yanny import yanny
+from .. import uniq
 #
 # Cache for the maskbits file.
 #
@@ -62,7 +67,7 @@ def sdss_astrombad(run, camcol, field, photolog_version='dr10'):
 
     Raises
     ------
-    ValueError
+    :exc:`ValueError`
         If the sizes of the arrays don't match or if the array values are out
         of bounds.
 
@@ -74,8 +79,6 @@ def sdss_astrombad(run, camcol, field, photolog_version='dr10'):
     problem with all camcols.
 
     """
-    from astropy.utils.data import download_file
-    from .yanny import yanny
     global opbadfields
     #
     # Check inputs
@@ -205,7 +208,7 @@ def sdss_flagname(flagname, flagvalue, concat=False):
 
     Raises
     ------
-    KeyError
+    :exc:`KeyError`
         If `flagname` is invalid
 
     Examples
@@ -255,7 +258,7 @@ def sdss_flagval(flagname, bitname):
 
     Raises
     ------
-    KeyError
+    :exc:`KeyError`
         If `flagname` or `bitname` are invalid names.
 
     Examples
@@ -287,10 +290,11 @@ def sdss_flagval(flagname, bitname):
     return flagvalue
 
 
-def sdss_objid(run, camcol, field, objnum, rerun=301, skyversion=None):
+def sdss_objid(run, camcol, field, objnum, rerun=301, skyversion=None,
+               firstfield=None):
     """Convert SDSS photometric identifiers into CAS-style ObjID.
 
-    Bits are assigned in objid thus:
+    Bits are assigned in ObjID thus:
 
     ===== ========== ===============================================
     Bits  Name       Comment
@@ -300,7 +304,7 @@ def sdss_objid(run, camcol, field, objnum, rerun=301, skyversion=None):
     48-58 rerun      number of pipeline rerun
     32-47 run        run number
     29-31 camcol     camera column (1-6)
-    28    firstField [is this the first field in segment?] 0 for now
+    28    firstField is this the first field in segment? Usually 0.
     16-27 field      field number within run
     0-15  object     object number within field
     ===== ========== ===============================================
@@ -310,8 +314,9 @@ def sdss_objid(run, camcol, field, objnum, rerun=301, skyversion=None):
     run, camcol, field, objnum : :class:`int` or array of int
         Run, camcol, field and object number within field.  If arrays are
         passed, all must have the same length.
-    rerun, skyversion : :class:`int` or array of int, optional
-        Rerun and skyversion usually don't change very much.  If supplied,
+    rerun, skyversion, firstfield : :class:`int` or array of int, optional
+        `rerun`, `skyversion` and `firstfield` usually don't change at all,
+        especially for ObjIDs in DR8 and later.  If supplied,
         make sure the size matches all the other values.
 
     Returns
@@ -321,13 +326,13 @@ def sdss_objid(run, camcol, field, objnum, rerun=301, skyversion=None):
 
     Raises
     ------
-    ValueError
+    :exc:`ValueError`
         If the sizes of the arrays don't match or if the array values are
         out of bounds.
 
     Notes
     -----
-    * ``firstField`` flag never set.
+    * The ``firstField`` flag is never set in ObjIDs from DR8 and later.
     * On 32-bit systems, makes sure to explicitly declare all inputs as
       64-bit integers.
 
@@ -339,6 +344,8 @@ def sdss_objid(run, camcol, field, objnum, rerun=301, skyversion=None):
     """
     if skyversion is None:
         skyversion = default_skyversion()
+    if firstfield is None:
+        firstfield = 0
     if isinstance(run, int):
         run = np.array([run], dtype=np.int64)
     if isinstance(camcol, int):
@@ -357,11 +364,15 @@ def sdss_objid(run, camcol, field, objnum, rerun=301, skyversion=None):
             skyversion = np.zeros(run.shape, dtype=np.int64) + default_skyversion()
         else:
             skyversion = np.array([skyversion], dtype=np.int64)
+    if isinstance(firstfield, int):
+        if firstfield == 0:
+            firstfield = np.zeros(run.shape, dtype=np.int64)
+        else:
+            firstfield = np.array([firstfield], dtype=np.int64)
 
     #
     # Check that all inputs have the same shape.
     #
-    firstfield = np.zeros(run.shape, dtype=np.int64)
     if run.shape != camcol.shape:
         raise ValueError("camcol.shape does not match run.shape!")
     if run.shape != field.shape:
@@ -372,9 +383,13 @@ def sdss_objid(run, camcol, field, objnum, rerun=301, skyversion=None):
         raise ValueError("rerun.shape does not match run.shape!")
     if run.shape != skyversion.shape:
         raise ValueError("skyversion.shape does not match run.shape!")
+    if run.shape != firstfield.shape:
+        raise ValueError("firstfield.shape does not match run.shape!")
     #
     # Check ranges of parameters
     #
+    if ((firstfield < 0) | (firstfield > 1)).any():
+        raise ValueError("firstfield values are out-of-bounds!")
     if ((skyversion < 0) | (skyversion >= 16)).any():
         raise ValueError("skyversion values are out-of-bounds!")
     if ((rerun < 0) | (rerun >= 2**11)).any():
@@ -441,7 +456,7 @@ def sdss_specobjid(plate, fiber, mjd, run2d, line=None, index=None):
 
     Raises
     ------
-    ValueError
+    :exc:`ValueError`
         If the sizes of the arrays don't match or if the array values are
         out of bounds.
 
@@ -461,7 +476,6 @@ def sdss_specobjid(plate, fiber, mjd, run2d, line=None, index=None):
     >>> print(sdss_specobjid(4055,408,55359,'v5_7_0'))
     [4565636362342690816]
     """
-    import re
     if line is not None and index is not None:
         raise ValueError("line and index inputs cannot both be non-zero!")
     if isinstance(plate, int):
@@ -555,7 +569,7 @@ def sdss_sweep_circle(ra, dec, radius, stype='star', allobj=False):
 
     Raises
     ------
-    PydlutilsException
+    :exc:`PydlutilsException`
         If :envvar:`PHOTO_SWEEP` is not set.
 
     Notes
@@ -563,8 +577,6 @@ def sdss_sweep_circle(ra, dec, radius, stype='star', allobj=False):
     Assumes that the sweep files exist in :envvar:`PHOTO_SWEEP` and
     that index files have been created.
     """
-    from .. import uniq
-    from .spheregroup import spherematch
     global sweep_cache
     #
     # Check values
@@ -684,7 +696,7 @@ def set_maskbits(idlutils_version='v5_5_24', maskbits_file=None):
 
     Raises
     ------
-    URLError
+    :exc:`URLError`
         If the data file could not be retrieved.
     """
     from astropy.utils.data import download_file
